# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/grid/messages/setup_messages.proto
"""Generated protocol buffer code."""
# third party
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


# syft absolute
from syft.proto.core.common import (
    common_object_pb2 as proto_dot_core_dot_common_dot_common__object__pb2,
)
from syft.proto.core.io import address_pb2 as proto_dot_core_dot_io_dot_address__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name="proto/grid/messages/setup_messages.proto",
    package="syft.grid.messages",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n(proto/grid/messages/setup_messages.proto\x12\x12syft.grid.messages\x1a%proto/core/common/common_object.proto\x1a\x1bproto/core/io/address.proto"\xa4\x01\n\x19\x43reateInitialSetUpMessage\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12&\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x15.syft.core.io.Address\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\'\n\x08reply_to\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x91\x01\n\x1a\x43reateInitialSetUpResponse\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x9a\x01\n\x0fGetSetUpMessage\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12&\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x15.syft.core.io.Address\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\'\n\x08reply_to\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x87\x01\n\x10GetSetUpResponse\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x9d\x01\n\x12UpdateSetupMessage\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12&\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x15.syft.core.io.Address\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\'\n\x08reply_to\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x8a\x01\n\x13UpdateSetupResponse\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Addressb\x06proto3',
    dependencies=[
        proto_dot_core_dot_common_dot_common__object__pb2.DESCRIPTOR,
        proto_dot_core_dot_io_dot_address__pb2.DESCRIPTOR,
    ],
)


_CREATEINITIALSETUPMESSAGE = _descriptor.Descriptor(
    name="CreateInitialSetUpMessage",
    full_name="syft.grid.messages.CreateInitialSetUpMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.CreateInitialSetUpMessage.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.CreateInitialSetUpMessage.address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.CreateInitialSetUpMessage.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reply_to",
            full_name="syft.grid.messages.CreateInitialSetUpMessage.reply_to",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=133,
    serialized_end=297,
)


_CREATEINITIALSETUPRESPONSE = _descriptor.Descriptor(
    name="CreateInitialSetUpResponse",
    full_name="syft.grid.messages.CreateInitialSetUpResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.CreateInitialSetUpResponse.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status_code",
            full_name="syft.grid.messages.CreateInitialSetUpResponse.status_code",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.CreateInitialSetUpResponse.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.CreateInitialSetUpResponse.address",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=300,
    serialized_end=445,
)


_GETSETUPMESSAGE = _descriptor.Descriptor(
    name="GetSetUpMessage",
    full_name="syft.grid.messages.GetSetUpMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.GetSetUpMessage.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.GetSetUpMessage.address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.GetSetUpMessage.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reply_to",
            full_name="syft.grid.messages.GetSetUpMessage.reply_to",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=448,
    serialized_end=602,
)


_GETSETUPRESPONSE = _descriptor.Descriptor(
    name="GetSetUpResponse",
    full_name="syft.grid.messages.GetSetUpResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.GetSetUpResponse.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status_code",
            full_name="syft.grid.messages.GetSetUpResponse.status_code",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.GetSetUpResponse.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.GetSetUpResponse.address",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=605,
    serialized_end=740,
)


_UPDATESETUPMESSAGE = _descriptor.Descriptor(
    name="UpdateSetupMessage",
    full_name="syft.grid.messages.UpdateSetupMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.UpdateSetupMessage.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.UpdateSetupMessage.address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.UpdateSetupMessage.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reply_to",
            full_name="syft.grid.messages.UpdateSetupMessage.reply_to",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=743,
    serialized_end=900,
)


_UPDATESETUPRESPONSE = _descriptor.Descriptor(
    name="UpdateSetupResponse",
    full_name="syft.grid.messages.UpdateSetupResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.UpdateSetupResponse.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status_code",
            full_name="syft.grid.messages.UpdateSetupResponse.status_code",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.UpdateSetupResponse.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.UpdateSetupResponse.address",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=903,
    serialized_end=1041,
)

_CREATEINITIALSETUPMESSAGE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_CREATEINITIALSETUPMESSAGE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_CREATEINITIALSETUPMESSAGE.fields_by_name[
    "reply_to"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_CREATEINITIALSETUPRESPONSE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_CREATEINITIALSETUPRESPONSE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_GETSETUPMESSAGE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_GETSETUPMESSAGE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_GETSETUPMESSAGE.fields_by_name[
    "reply_to"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_GETSETUPRESPONSE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_GETSETUPRESPONSE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_UPDATESETUPMESSAGE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_UPDATESETUPMESSAGE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_UPDATESETUPMESSAGE.fields_by_name[
    "reply_to"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_UPDATESETUPRESPONSE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_UPDATESETUPRESPONSE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
DESCRIPTOR.message_types_by_name[
    "CreateInitialSetUpMessage"
] = _CREATEINITIALSETUPMESSAGE
DESCRIPTOR.message_types_by_name[
    "CreateInitialSetUpResponse"
] = _CREATEINITIALSETUPRESPONSE
DESCRIPTOR.message_types_by_name["GetSetUpMessage"] = _GETSETUPMESSAGE
DESCRIPTOR.message_types_by_name["GetSetUpResponse"] = _GETSETUPRESPONSE
DESCRIPTOR.message_types_by_name["UpdateSetupMessage"] = _UPDATESETUPMESSAGE
DESCRIPTOR.message_types_by_name["UpdateSetupResponse"] = _UPDATESETUPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateInitialSetUpMessage = _reflection.GeneratedProtocolMessageType(
    "CreateInitialSetUpMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEINITIALSETUPMESSAGE,
        "__module__": "proto.grid.messages.setup_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.CreateInitialSetUpMessage)
    },
)
_sym_db.RegisterMessage(CreateInitialSetUpMessage)

CreateInitialSetUpResponse = _reflection.GeneratedProtocolMessageType(
    "CreateInitialSetUpResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEINITIALSETUPRESPONSE,
        "__module__": "proto.grid.messages.setup_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.CreateInitialSetUpResponse)
    },
)
_sym_db.RegisterMessage(CreateInitialSetUpResponse)

GetSetUpMessage = _reflection.GeneratedProtocolMessageType(
    "GetSetUpMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETSETUPMESSAGE,
        "__module__": "proto.grid.messages.setup_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.GetSetUpMessage)
    },
)
_sym_db.RegisterMessage(GetSetUpMessage)

GetSetUpResponse = _reflection.GeneratedProtocolMessageType(
    "GetSetUpResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETSETUPRESPONSE,
        "__module__": "proto.grid.messages.setup_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.GetSetUpResponse)
    },
)
_sym_db.RegisterMessage(GetSetUpResponse)

UpdateSetupMessage = _reflection.GeneratedProtocolMessageType(
    "UpdateSetupMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATESETUPMESSAGE,
        "__module__": "proto.grid.messages.setup_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.UpdateSetupMessage)
    },
)
_sym_db.RegisterMessage(UpdateSetupMessage)

UpdateSetupResponse = _reflection.GeneratedProtocolMessageType(
    "UpdateSetupResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATESETUPRESPONSE,
        "__module__": "proto.grid.messages.setup_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.UpdateSetupResponse)
    },
)
_sym_db.RegisterMessage(UpdateSetupResponse)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/lib/numpy/array.proto
"""Generated protocol buffer code."""
# third party
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="proto/lib/numpy/array.proto",
    package="syft.lib.numpy",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x1bproto/lib/numpy/array.proto\x12\x0esyft.lib.numpy"O\n\nNumpyProto\x12\x14\n\narrow_data\x18\x01 \x01(\x0cH\x00\x12\x14\n\nproto_data\x18\x02 \x01(\x0cH\x00\x12\r\n\x05\x64type\x18\x03 \x01(\tB\x06\n\x04\x64\x61tab\x06proto3',
)


_NUMPYPROTO = _descriptor.Descriptor(
    name="NumpyProto",
    full_name="syft.lib.numpy.NumpyProto",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="arrow_data",
            full_name="syft.lib.numpy.NumpyProto.arrow_data",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="proto_data",
            full_name="syft.lib.numpy.NumpyProto.proto_data",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dtype",
            full_name="syft.lib.numpy.NumpyProto.dtype",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="data",
            full_name="syft.lib.numpy.NumpyProto.data",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=47,
    serialized_end=126,
)

_NUMPYPROTO.oneofs_by_name["data"].fields.append(
    _NUMPYPROTO.fields_by_name["arrow_data"]
)
_NUMPYPROTO.fields_by_name["arrow_data"].containing_oneof = _NUMPYPROTO.oneofs_by_name[
    "data"
]
_NUMPYPROTO.oneofs_by_name["data"].fields.append(
    _NUMPYPROTO.fields_by_name["proto_data"]
)
_NUMPYPROTO.fields_by_name["proto_data"].containing_oneof = _NUMPYPROTO.oneofs_by_name[
    "data"
]
DESCRIPTOR.message_types_by_name["NumpyProto"] = _NUMPYPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NumpyProto = _reflection.GeneratedProtocolMessageType(
    "NumpyProto",
    (_message.Message,),
    {
        "DESCRIPTOR": _NUMPYPROTO,
        "__module__": "proto.lib.numpy.array_pb2"
        # @@protoc_insertion_point(class_scope:syft.lib.numpy.NumpyProto)
    },
)
_sym_db.RegisterMessage(NumpyProto)


# @@protoc_insertion_point(module_scope)



# stdlib
import math
import time

# third party
import torch
from torch import nn
from transformers import AutoModel
from transformers.models.distilbert.modeling_distilbert import (
    create_sinusoidal_embeddings,
)
from transformers.models.distilbert.modeling_distilbert import DistilBertConfig

# syft absolute
from syft import SyModule
from syft.core.plan.plan_builder import ROOT_CLIENT


class Embeddings(SyModule):
    def __init__(self, config: DistilBertConfig, **kwargs) -> None:  # type: ignore
        super().__init__(**kwargs)
        self.config = config
        self.word_embeddings = nn.Embedding(
            config.vocab_size, config.dim, padding_idx=config.pad_token_id
        )
        self.position_embeddings = nn.Embedding(
            config.max_position_embeddings, config.dim
        )

        if config.sinusoidal_pos_embds:
            create_sinusoidal_embeddings(
                n_pos=config.max_position_embeddings,
                dim=config.dim,
                out=self.position_embeddings.weight,
            )

        self.LayerNorm = nn.LayerNorm(config.dim, eps=1e-12)
        self.dropout = nn.Dropout(config.dropout)

    def forward(self, input_ids: torch.LongTensor) -> torch.FloatTensor:
        remote_torch = ROOT_CLIENT.torch

        seq_length = input_ids.size(1)
        # TODO setting device from input_ids from remotely created tensor throws KeyError: UID <...>.
        position_ids = remote_torch.arange(seq_length)  # (max_seq_length)
        position_ids = remote_torch.unsqueeze(position_ids, 0).expand(
            input_ids.size(0), input_ids.size(1)
        )  # (bs, max_seq_length)

        word_embeddings = self.word_embeddings(input_ids)  # (bs, max_seq_length, dim)
        position_embeddings = self.position_embeddings(
            position_ids
        )  # (bs, max_seq_length, dim)

        embeddings = word_embeddings + position_embeddings  # (bs, max_seq_length, dim)
        embeddings = self.LayerNorm(embeddings)  # (bs, max_seq_length, dim)
        embeddings = self.dropout(embeddings)  # (bs, max_seq_length, dim)
        return embeddings


class MultiHeadSelfAttention(SyModule):
    def __init__(self, config: DistilBertConfig, **kwargs) -> None:  # type: ignore
        super().__init__(**kwargs)

        if config.dim % config.n_heads != 0:
            raise ValueError("`config.dim` should be a multiple of `config.n_heads`")

        self.n_heads = config.n_heads
        self.dim = config.dim
        self.dropout = nn.Dropout(p=config.attention_dropout)

        self.q_lin = nn.Linear(in_features=config.dim, out_features=config.dim)
        self.k_lin = nn.Linear(in_features=config.dim, out_features=config.dim)
        self.v_lin = nn.Linear(in_features=config.dim, out_features=config.dim)
        self.out_lin = nn.Linear(in_features=config.dim, out_features=config.dim)

    def shape(self, x: torch.Tensor, bs: int, dim_per_head: int) -> torch.Tensor:
        """separate heads for linear layers"""
        return x.view(bs, -1, self.n_heads, dim_per_head).transpose(1, 2)

    def unshape(self, x: torch.Tensor, bs: int, dim_per_head: int) -> torch.Tensor:
        """group heads"""
        return x.transpose(1, 2).contiguous().view(bs, -1, self.n_heads * dim_per_head)

    def forward(
        self,
        query: torch.Tensor,
        key: torch.Tensor,
        value: torch.Tensor,
        mask: torch.Tensor,
    ) -> torch.Tensor:
        """
        Parameters:
            query: torch.tensor(bs, seq_length, dim)
            key: torch.tensor(bs, seq_length, dim)
            value: torch.tensor(bs, seq_length, dim)
            mask: torch.tensor(bs, seq_length)
        Returns:
            weights: torch.tensor(bs, n_heads, seq_length, seq_length)
        """
        remote_torch = ROOT_CLIENT.torch

        bs = query.size(0)
        k_length = key.size(1)

        dim_per_head = self.dim // self.n_heads
        mask_reshp = (bs, 1, 1, k_length)

        # Linear
        q = self.shape(
            self.q_lin(query), bs, dim_per_head
        )  # (bs, n_heads, q_length, dim_per_head)
        k = self.shape(
            self.k_lin(key), bs, dim_per_head
        )  # (bs, n_heads, k_length, dim_per_head)
        v = self.shape(
            self.v_lin(value), bs, dim_per_head
        )  # (bs, n_heads, k_length, dim_per_head)

        q = q / math.sqrt(dim_per_head)  # (bs, n_heads, q_length, dim_per_head)
        scores = remote_torch.matmul(
            q, k.transpose(2, 3)
        )  # (bs, n_heads, q_length, k_length)

        mask = (mask == 0).view(*mask_reshp)
        mask = mask.expand(-1, scores.size(1), scores.size(2), -1)

        # TODO this is equivalent to the two above lines, expand_as does not work.
        # mask = (mask == 0).view(*mask_reshp).expand_as(scores)

        # Softmax
        scores.masked_fill_(mask, -float("inf"))  # (bs, n_heads, q_length, k_length)
        weights = remote_torch.softmax(
            scores, dim=-1
        )  # (bs, n_heads, q_length, k_length)
        weights = self.dropout(weights)  # (bs, n_heads, q_length, k_length)

        context = remote_torch.matmul(
            weights, v
        )  # (bs, n_heads, q_length, dim_per_head)
        context = self.unshape(context, bs, dim_per_head)  # (bs, q_length, dim)
        context = self.out_lin(context)  # (bs, q_length, dim)

        return context


class FFN(SyModule):
    def __init__(self, config: DistilBertConfig, **kwargs) -> None:  # type: ignore
        super().__init__(**kwargs)
        self.dropout = nn.Dropout(p=config.dropout)
        self.seq_len_dim = 1
        self.lin1 = nn.Linear(in_features=config.dim, out_features=config.hidden_dim)
        self.lin2 = nn.Linear(in_features=config.hidden_dim, out_features=config.dim)

        if config.activation == "gelu":
            self.activation = ROOT_CLIENT.torch.nn.functional.gelu
        elif config.activation == "relu":
            self.activation = ROOT_CLIENT.torch.nn.functional.relu
        else:
            raise ValueError(
                f"activation ({config.activation}) must be in ['relu', 'gelu']"
            )

    def forward(self, input: torch.Tensor) -> torch.Tensor:
        x = self.lin1(input)
        x = self.activation(x)
        x = self.lin2(x)
        x = self.dropout(x)
        return x


class TransformerBlock(SyModule):
    def __init__(self, config: DistilBertConfig, **kwargs) -> None:  # type: ignore
        super().__init__(**kwargs)
        if config.dim % config.n_heads != 0:
            raise ValueError("`config.dim` should be a multiple of `config.n_heads`")

        attn_dummy_inputs = {
            "query": kwargs["inputs"]["x"],
            "key": kwargs["inputs"]["x"],
            "value": kwargs["inputs"]["x"],
            "mask": kwargs["inputs"]["attn_mask"],
        }
        self.attention = MultiHeadSelfAttention(config, inputs=attn_dummy_inputs)

        ffn_dummy_inputs = {"input": kwargs["inputs"]["x"]}
        self.ffn = FFN(config, inputs=ffn_dummy_inputs)

        self.sa_layer_norm = nn.LayerNorm(normalized_shape=config.dim, eps=1e-12)
        self.output_layer_norm = nn.LayerNorm(normalized_shape=config.dim, eps=1e-12)

    def forward(self, x: torch.Tensor, attn_mask: torch.Tensor) -> torch.Tensor:
        # Self-Attention
        sa_output = self.attention(query=x, key=x, value=x, mask=attn_mask)[0]

        sa_output = self.sa_layer_norm(sa_output + x)  # (bs, seq_length, dim)

        # Feed Forward Network
        ffn_output = self.ffn(input=sa_output)[0]  # (bs, seq_length, dim)
        ffn_output = self.output_layer_norm(
            ffn_output + sa_output
        )  # (bs, seq_length, dim)

        return ffn_output


class Transformer(SyModule):
    def __init__(self, config: DistilBertConfig, **kwargs) -> None:  # type: ignore

        t0 = time.time()

        super().__init__(**kwargs)
        self.n_layers = config.n_layers

        self.layer = nn.ModuleList(
            [
                TransformerBlock(config, inputs=kwargs["inputs"])
                for _ in range(self.n_layers)
            ]
        )

        print(f"transformer init: {time.time() - t0:.2f} s")

    def forward(self, x: torch.Tensor, attn_mask: torch.Tensor) -> torch.Tensor:
        """
        - SyModule does not work; multiple inputs
        - getattr does not work;
        """
        t0 = time.time()
        hidden_state = x

        # TODO fix ModuleList.__iter__; items in iter need to be ModulePointer
        for i in range(self.n_layers):
            layer = self.layer[i]
            hidden_state = layer(x=hidden_state, attn_mask=attn_mask)[0]

        print(f"transformer forward: {time.time() - t0:.2f} s")
        return hidden_state


class SyDistilBert(SyModule):
    def __init__(self, config: DistilBertConfig, **kwargs) -> None:  # type: ignore
        """
        SyDistilBert is a re-implementation of huggingface DistilBert in pysyft,
        with all non-torch-native submodules rewritten as SyModules.

        Use the `from_pretrained` or `from_config` classmethods to instantiate this
        model from an existing HuggingFace pretrained model or config.
        """
        super().__init__(**kwargs)
        self.config = config

        # Embeddings
        embedding_inputs = {"input_ids": kwargs["inputs"]["input_ids"]}
        self.embeddings = Embeddings(config=config, inputs=embedding_inputs)

        # Transformer
        transformer_x = torch.rand(*kwargs["inputs"]["input_ids"].size(), config.dim)
        transformer_mask = kwargs["inputs"]["attention_mask"]
        transformer_inputs = {"x": transformer_x, "attn_mask": transformer_mask}

        self.transformer = Transformer(config=config, inputs=transformer_inputs)

    def forward(
        self, input_ids: torch.Tensor, attention_mask: torch.Tensor
    ) -> torch.Tensor:
        # [B, S] -> [B, S, D]
        input_embeds = self.embeddings(input_ids=input_ids)[0]

        # [B, S, D] -> [B, S, D]
        out = self.transformer(x=input_embeds, attn_mask=attention_mask)[0]
        return out

    @classmethod
    def from_pretrained(cls, model_name: str) -> "SyDistilBert":
        # Make dummy inputs
        dummy_x = torch.ones(2, 3, dtype=torch.long)
        dummy_mask = torch.ones(2, 3, dtype=torch.long)

        dummy_inputs = {"input_ids": dummy_x, "attention_mask": dummy_mask}

        # Load huggingface model
        hf_model = AutoModel.from_pretrained(model_name)

        # Construct model
        model = cls(hf_model.config, inputs=dummy_inputs)

        # Load weights
        model.load_state_dict(hf_model.state_dict())

        return model

    @classmethod
    def from_config(cls, config: DistilBertConfig) -> "SyDistilBert":
        # Make dummy inputs
        dummy_x = torch.ones(2, 3, dtype=torch.long)
        dummy_mask = torch.ones(2, 3, dtype=torch.long)

        dummy_inputs = {"input_ids": dummy_x, "attention_mask": dummy_mask}

        # Construct model
        model = cls(config, inputs=dummy_inputs)

        return model



"""
The purpose of this application is to allow us to dev and test PySyft
functionality on an actual local network. This is NOT meant to be run in
production (that's the *actual* grid's job).
"""
# third party
import flask
from flask import Flask
from flask import Response

# syft absolute
from syft import serialize
from syft.core.common.message import SignedImmediateSyftMessageWithReply
from syft.core.common.message import SignedImmediateSyftMessageWithoutReply
from syft.core.common.serde.deserialize import _deserialize
from syft.core.node.network.network import Network
from syft.grid.services.signaling_service import PullSignalingService
from syft.grid.services.signaling_service import PushSignalingService
from syft.grid.services.signaling_service import RegisterDuetPeerService
from syft.logger import info


def signaling_server(port: int = 5000, host: str = "127.0.0.1") -> None:  # nosec
    app = Flask(__name__)

    network = Network(name="om-net")
    network.immediate_services_without_reply.append(PushSignalingService)
    network.immediate_services_with_reply.append(PullSignalingService)
    network.immediate_services_with_reply.append(RegisterDuetPeerService)
    network._register_services()  # re-register all services including SignalingService

    @app.route("/metadata")
    def get_metadata() -> flask.Response:
        metadata = network.get_metadata_for_client()
        metadata_proto = serialize(metadata)
        r = Response(
            response=metadata_proto.SerializeToString(),
            status=200,
        )
        r.headers["Content-Type"] = "application/octet-stream"
        return r

    @app.route("/", methods=["POST"])
    def process_network_msgs() -> flask.Response:
        data = flask.request.get_data()
        obj_msg = _deserialize(blob=data, from_bytes=True)
        if isinstance(obj_msg, SignedImmediateSyftMessageWithReply):
            info(
                f"Signaling server SignedImmediateSyftMessageWithReply: {obj_msg.message} watch"
            )
            reply = network.recv_immediate_msg_with_reply(msg=obj_msg)
            r = Response(response=serialize(reply, to_bytes=True), status=200)
            r.headers["Content-Type"] = "application/octet-stream"
            return r
        elif isinstance(obj_msg, SignedImmediateSyftMessageWithoutReply):
            info(
                f"Signaling server SignedImmediateSyftMessageWithoutReply: {obj_msg.message} watch"
            )
            network.recv_immediate_msg_without_reply(msg=obj_msg)
            r = Response(status=200)
            return r
        else:
            info(
                f"Signaling server SignedImmediateSyftMessageWithoutReply: {obj_msg.message} watch"
            )
            network.recv_eventual_msg_without_reply(msg=obj_msg)
            r = Response(status=200)
            return r

    app.run(host=host, port=port)



# third party
import pandas as pd

# syft relative
from ...generate_wrapper import GenerateWrapper
from ...lib.python.list import List
from ...lib.python.primitive_factory import PrimitiveFactory
from ...proto.lib.pandas.categorical_pb2 import (
    PandasCategorical as PandasCategorical_PB,
)


def object2proto(obj: pd.Categorical) -> PandasCategorical_PB:
    pd_codes_list = PrimitiveFactory.generate_primitive(value=obj.codes.tolist())
    codes_proto = pd_codes_list._object2proto()
    pd_cat_list = PrimitiveFactory.generate_primitive(value=obj.categories.tolist())
    cat_proto = pd_cat_list._object2proto()

    return PandasCategorical_PB(
        id=codes_proto.id,
        codes=codes_proto,
        categories=cat_proto,
        ordered=obj.ordered,
    )


def proto2object(proto: PandasCategorical_PB) -> pd.Categorical:
    categories = List._proto2object(proto.categories).upcast()
    codes = List._proto2object(proto.codes).upcast()
    ordered = proto.ordered
    return pd.Categorical.from_codes(codes, categories=categories, ordered=ordered)


GenerateWrapper(
    wrapped_type=pd.Categorical,
    import_path="pandas.Categorical",
    protobuf_scheme=PandasCategorical_PB,
    type_object2proto=object2proto,
    type_proto2object=proto2object,
)



"""Serde method for pd.Series."""

# third party
import pandas as pd
import pyarrow as pa

# syft relative
from ...generate_wrapper import GenerateWrapper
from ...proto.lib.pandas.series_pb2 import PandasSeries as PandasSeries_PB


def object2proto(obj: pd.Series) -> PandasSeries_PB:
    """Convert pd.Series to PandasDataFrame_PB with pyarrow.

    Args:
        obj: target Series

    Returns:
        Serialized version of Series, which will be used to reconstruction.

    """
    # https://arrow.apache.org/docs/python/pandas.html
    # series must either be converted to a dataframe or use pa.Array
    # however pa.Array mentions you must account for the null values yourself
    dataframe = obj.to_frame()
    schema = pa.Schema.from_pandas(dataframe)
    table = pa.Table.from_pandas(dataframe)
    sink = pa.BufferOutputStream()

    writer = pa.ipc.new_file(sink, schema)
    writer.write(table)
    writer.close()

    buf = sink.getvalue()

    siz = len(buf)
    df_bytes = pa.compress(buf, asbytes=True)

    return PandasSeries_PB(series=df_bytes, decompressed_size=siz)


def proto2object(proto: PandasSeries_PB) -> pd.Series:
    """Convert PandasSeries_PB to pd.Series with pyarrow.

    Args:
        proto: Serialized version of Series, which will be used to reconstruction.

    Returns:
        Re-constructed Series.

    """
    buf = pa.decompress(proto.series, decompressed_size=proto.decompressed_size)
    dataframe = pa.ipc.open_file(buf).read_pandas()
    # we know that this is a series being stored as a dataframe so just grab the first
    return dataframe[dataframe.columns[0]]


GenerateWrapper(
    wrapped_type=pd.Series,
    import_path="pandas.Series",
    protobuf_scheme=PandasSeries_PB,
    type_object2proto=object2proto,
    type_proto2object=proto2object,
)



# third party
from transformers.tokenization_utils_base import BatchEncoding

# syft relative
from ...generate_wrapper import GenerateWrapper
from ...lib.python.dict import Dict
from ...lib.python.primitive_factory import PrimitiveFactory
from ...proto.lib.transformers.batch_encoding_pb2 import (
    BatchEncoding as BatchEncoding_PB,
)


def object2proto(obj: BatchEncoding) -> BatchEncoding_PB:
    obj_dict = PrimitiveFactory.generate_primitive(value=obj.data)
    return BatchEncoding_PB(
        id=obj_dict.id._object2proto(), data=obj_dict._object2proto()
    )


def proto2object(proto: BatchEncoding_PB) -> BatchEncoding:
    obj_dict = Dict._proto2object(proto=proto.data)
    return BatchEncoding(data=obj_dict.data)


GenerateWrapper(
    wrapped_type=BatchEncoding,
    import_path="transformers.tokenization_utils_base.BatchEncoding",
    protobuf_scheme=BatchEncoding_PB,
    type_object2proto=object2proto,
    type_proto2object=proto2object,
)
